@@ -409,22 +409,15 @@ class CephFSDriverTestCase(test.TestCase):
             group_delete_prefix, group_delete_dict)
 
     def test_create_share_group_snapshot(self):
-        group_snapshot_create_prefix = "fs subvolumegroup snapshot create"
+        msg = ("Share group snapshot feature is no longer supported in "
+               "mainline CephFS (existing group snapshots can still be "
+               "listed and deleted).")
+        driver.rados_command.side_effect = exception.ShareBackendException(msg)
 
-        group_snapshot_create_dict = {
-            "vol_name": self._driver.volname,
-            "group_name": "sgid",
-            "snap_name": "snapid",
-        }
-
-        self._driver.create_share_group_snapshot(self._context, {
-            'share_group_id': 'sgid',
-            'id': 'snapid',
-        })
-
-        driver.rados_command.assert_called_once_with(
-            self._driver.rados_client,
-            group_snapshot_create_prefix, group_snapshot_create_dict)
+        self.assertRaises(exception.ShareBackendException,
+                          self._driver.create_share_group_snapshot,
+                          self._context, {'share_group_id': 'sgid',
+                                          'id': 'snapid'})
 
     def test_delete_share_group_snapshot(self):
         group_snapshot_delete_prefix = "fs subvolumegroup snapshot rm"
@@ -549,11 +542,14 @@ class CephFSDriverTestCase(test.TestCase):
         self._driver.get_configured_ip_versions = mock.Mock(return_value=[4])
         self._driver.configuration.local_conf.set_override(
             'reserved_share_percentage', 5)
+        self._driver.configuration.local_conf.set_override(
+            'reserved_share_from_snapshot_percentage', 2)
 
         self._driver._update_share_stats()
         result = self._driver._stats
 
         self.assertEqual(5, result['pools'][0]['reserved_percentage'])
+        self.assertEqual(2, result['pools'][0]['reserved_snapshot_percentage'])
         self.assertEqual(164.94, result['pools'][0]['total_capacity_gb'])
         self.assertEqual(149.84, result['pools'][0]['free_capacity_gb'])
         self.assertTrue(result['ipv4_support'])
@@ -710,6 +706,37 @@ class NativeProtocolHelperTestCase(test.TestCase):
 
         self.assertEqual(2, driver.rados_command.call_count)
 
+    def test_deny_access_missing_access_rule(self):
+        access_deny_prefix = "fs subvolume deauthorize"
+
+        exception_msg = (
+            f"json_command failed - prefix=fs subvolume deauthorize, "
+            f"argdict='vol_name': {self._native_protocol_helper.volname}, "
+            f"'sub_name': '{self._share['id']}', 'auth_id': 'alice', "
+            f"'format': 'json' - exception message: [errno -2] "
+            f"auth ID: alice doesn't exist.")
+
+        driver.rados_command.side_effect = exception.ShareBackendException(
+            msg=exception_msg)
+
+        access_deny_dict = {
+            "vol_name": self._native_protocol_helper.volname,
+            "sub_name": self._share["id"],
+            "auth_id": "alice",
+        }
+
+        self._native_protocol_helper._deny_access(self._context, self._share, {
+            'access_level': 'rw',
+            'access_type': 'cephx',
+            'access_to': 'alice'
+        })
+
+        driver.rados_command.assert_called_once_with(
+            self._native_protocol_helper.rados_client,
+            access_deny_prefix, access_deny_dict)
+
+        self.assertEqual(1, driver.rados_command.call_count)
+
     def test_update_access_add_rm(self):
         alice = {
             'id': 'instance_mapping_id1',
